import pytest

from src.json_advanced.json_encoder import dumps


def test_function_serialization() -> None:
    def test_func() -> None:
        pass

    data = {"func": test_func}
    with pytest.warns(
        UserWarning, match="Attempting to serialize function/coroutine.*"
    ):
        with pytest.raises(
            ValueError, match="Attempting to serialize function/coroutine.*"
        ):
            dumps(data)


@pytest.mark.asyncio
async def test_coroutine_serialization() -> None:
    async def test_coro() -> None:
        pass

    coro = test_coro()
    try:
        data = {"coro": coro}
        with pytest.warns(
            UserWarning, match="Attempting to serialize function/coroutine.*"
        ):
            with pytest.raises(
                ValueError,
                match="Attempting to serialize function/coroutine.*",
            ):
                dumps(data)
    finally:
        await coro  # Clean up the coroutine
